@@ -17,7 +17,7 @@ use Carp;
 use Fcntl;
 use HiPi qw( :rpi );
 
-our $VERSION ='0.78';
+our $VERSION ='0.79';
 
 __PACKAGE__->create_accessors();
 
@@ -77,6 +77,11 @@ sub _do_setpud {
     return HiPi::Device::GPIO->set_pin_pud($self->pinid, $pudval);
 }
 
+sub _do_getpud {
+    my($self) = @_;
+    return HiPi::Device::GPIO->get_pin_pud($self->pinid);
+}
+
 sub _do_activelow {
     my($self, $newval) = @_;
     
