@@ -15,7 +15,7 @@ use warnings;
 use parent qw( HiPi::Class );
 use HiPi qw( :rpi );
 
-our $VERSION ='0.78';
+our $VERSION ='0.79';
 
 __PACKAGE__->create_ro_accessors( qw( pinid ) );
 
@@ -56,6 +56,12 @@ sub set_pud {
     return $rval;
 }
 
+sub get_pud {
+    my( $self ) = @_;
+    my $rval = $self->_do_getpud();
+    return $rval;
+}
+
 sub get_function {
     my( $self ) = @_;
     return $self->_do_get_function_name();
